@@ -114,47 +114,50 @@ public class Agent {
 			System.exit(1);
 		}
 
-		// Systemプロパティ
-		m_log.info("starting Hinemos Agent...");
-		m_log.info("java.vm.version = " + System.getProperty("java.vm.version"));
-		m_log.info("java.vm.vendor = " + System.getProperty("java.vm.vendor"));
-		m_log.info("java.home = " + System.getProperty("java.home"));
-		m_log.info("os.name = " + System.getProperty("os.name"));
-		m_log.info("os.arch = " + System.getProperty("os.arch"));
-		m_log.info("os.version = " + System.getProperty("os.version"));
-		m_log.info("user.name = " + System.getProperty("user.name"));
-		m_log.info("user.dir = " + System.getProperty("user.dir"));
-		m_log.info("user.country = " + System.getProperty("user.country"));
-		m_log.info("user.language = " + System.getProperty("user.language"));
-		m_log.info("file.encoding = " + System.getProperty("file.encoding"));
+		try {
+			// Systemプロパティ
+			m_log.info("starting Hinemos Agent...");
+			m_log.info("java.vm.version = " + System.getProperty("java.vm.version"));
+			m_log.info("java.vm.vendor = " + System.getProperty("java.vm.vendor"));
+			m_log.info("java.home = " + System.getProperty("java.home"));
+			m_log.info("os.name = " + System.getProperty("os.name"));
+			m_log.info("os.arch = " + System.getProperty("os.arch"));
+			m_log.info("os.version = " + System.getProperty("os.version"));
+			m_log.info("user.name = " + System.getProperty("user.name"));
+			m_log.info("user.dir = " + System.getProperty("user.dir"));
+			m_log.info("user.country = " + System.getProperty("user.country"));
+			m_log.info("user.language = " + System.getProperty("user.language"));
+			m_log.info("file.encoding = " + System.getProperty("file.encoding"));
 
-		// TODO プロパティファイルのフォルダの親がagentHome。
-		// あまり良くない実装なので、修正予定。
-		File file = new File(args[0]);
-		agentHome = file.getParentFile().getParent() + "/";
-		m_log.info("agentHome=" + agentHome);
+			// TODO プロパティファイルのフォルダの親がagentHome。
+			// あまり良くない実装なので、修正予定。
+			File file = new File(args[0]);
+			agentHome = file.getParentFile().getParent() + "/";
+			m_log.info("agentHome=" + agentHome);
 
-		// 起動時刻
-		long startDate = System.currentTimeMillis();
-		m_log.info("start date = " + new Date(startDate) + "(" + startDate + ")");
-		agentInfo.setStartupTime(startDate);
+			// 起動時刻
+			long startDate = System.currentTimeMillis();
+			m_log.info("start date = " + new Date(startDate) + "(" + startDate + ")");
+			agentInfo.setStartupTime(startDate);
 
-		// Agent設定の初期化
-		m_log.info("Agent.properties = " + args[0]);
-		// ログ再読み込みの機構初期化
-		m_log.info("log4j.properties = " + args[1]);
+			// Agent設定の初期化
+			m_log.info("Agent.properties = " + args[0]);
+			// ログ再読み込みの機構初期化
+			m_log.info("log4j.properties = " + args[1]);
 
-		// Agentインスタンス作成
-		Agent agent = new Agent(args[0], args[1]);
+			// Agentインスタンス作成
+			Agent agent = new Agent(args[0], args[1]);
 
-		//エージェント処理開始
-		agent.exec();
+			// エージェント処理開始
+			agent.exec();
 
-		m_log.info("Hinemos Agent started");
+			m_log.info("Hinemos Agent started");
 
-
-		//終了待ち
-		agent.waitAwakeAgent();
+			// 終了待ち
+			agent.waitAwakeAgent();
+		} catch (Throwable e){
+			m_log.error("Agent.java: Runtime Exception Occurred. " + e.getClass().getName()+ ", " + e.getMessage(), e);
+		}
 	}
 
 	/**
@@ -164,11 +167,19 @@ public class Agent {
 	 */
 	public void waitAwakeAgent () {
 		final int BUFSIZE = 1;
-		final int port = 24005;
+		int port = 24005;
 		byte[] buf = new byte[BUFSIZE];
 		InetAddress cAddr;		// マネージャのIPアドレス
 		int cPort;				// マネージャのポート
 		DatagramSocket sock = null;
+		
+		try {
+			port = Integer.parseInt(AgentProperties.getProperty("awake.port", "24005"));
+		} catch (Exception e) {
+			m_log.warn("awake.port is invalid. " + e.getMessage());
+		}
+		m_log.info("awake.port(udp)=" + port);
+		
 		try {
 			sock = new DatagramSocket(port);
 		} catch (Exception e) {
@@ -210,7 +221,7 @@ public class Agent {
 		final int port = 24005;
 		ServerSocket servSock = null;
 		Socket clntSock = null;
-		
+
 		final int BUFSIZE = 256;
 		int tmpRecvMsgSize = 0;
 		int recvMsgSize = 0;
@@ -271,13 +282,13 @@ public class Agent {
 		//-- 初期処理
 		//------------
 
+		//プロパティファイル読み込み初期化
+		AgentProperties.init(propFileName);
+
 		// エージェントのIPアドレス、ホスト名をログに出力。
 		getAgentInfo();
 		m_log.info(getAgentStr());
 
-		//プロパティファイル読み込み初期化
-		AgentProperties.init(propFileName);
-
 		// log4j設定ファイル再読み込み設定
 		if(log4jFileName == null){
 			m_log.error("log4j.properties does not specify!");
@@ -298,7 +309,7 @@ public class Agent {
 		try {
 			String strConnect = AgentProperties.getProperty("connect.timeout");
 			if (strConnect != null) {
-				requestTimeout = Integer.parseInt(strConnect);
+				connectTimeout = Integer.parseInt(strConnect);
 			}
 			String strRequest = AgentProperties.getProperty("request.timeout");
 			if (strRequest != null) {
@@ -437,7 +448,7 @@ public class Agent {
 				m_reconfigLog4jInterval,m_reconfigLog4jInterval,TimeUnit.SECONDS);
 
 		// ログファイル読み込みスレッド開始
-		LogfileMonitorManager manager = new LogfileMonitorManager(null);
+		LogfileMonitorManager manager = new LogfileMonitorManager(m_sendQueue);
 		manager.start();
 
 	}
@@ -665,11 +676,13 @@ public class Agent {
 						"," + newIpAddressList.size());
 				agentInfo.getIpAddress().clear();
 				agentInfo.getIpAddress().addAll(newIpAddressList);
+				ReceiveTopic.setReloadFlg(true);
 			} else {
 				if (!agentInfo.getIpAddress().containsAll(newIpAddressList)) {
 					m_log.info("ipAddress change");
 					agentInfo.getIpAddress().clear();
 					agentInfo.getIpAddress().addAll(newIpAddressList);
+					ReceiveTopic.setReloadFlg(true);
 				}
 			}
 		} catch (SocketException e) {
