@@ -29,6 +29,7 @@ import org.apache.commons.logging.LogFactory;
 import com.clustercontrol.agent.bean.TopicFlagConstant;
 import com.clustercontrol.agent.custom.CollectorManager;
 import com.clustercontrol.agent.custom.CommandCollector;
+import com.clustercontrol.agent.custom.CommandCollector.CollectorId;
 import com.clustercontrol.agent.job.CheckSumThread;
 import com.clustercontrol.agent.job.CommandThread;
 import com.clustercontrol.agent.job.FileListThread;
@@ -79,6 +80,7 @@ public class ReceiveTopic extends Thread {
 	// マネージャと接続できている場合、フラグはtrueになる。
 	private long disconnectCounter = 1;
 	private static boolean m_clearFlg = false;
+	private static boolean m_reloadFlg = false;
 
 	// 最後に受信した設定情報更新日時
 	private static SettingUpdateInfo commandMonitorLastUpdateInfo = null;
@@ -234,11 +236,12 @@ public class ReceiveTopic extends Thread {
 					continue; // whileまで戻る。
 				}
 				/*
-				 * マネージャと接続直後の場合、ここで転送ログファイル、コマンド監視情報のリストを受け取る。
+				 * マネージャと接続直後の場合、ここで転送ログファイル、カスタム監視情報のリストを受け取り、リロードフラグをオフにする。
 				 */
 				if (disconnectCounter != 0) {
 					reloadLogfileMonitor();
 					reloadCommandMonitoring(updateInfo);
+					setReloadFlg(false);
 				}
 				disconnectCounter = 0;
 				setClearFlg(false);
@@ -247,6 +250,16 @@ public class ReceiveTopic extends Thread {
 					// コマンド監視のリロードを行う
 					reloadCommandMonitoring(updateInfo);
 				}
+				
+				// 監視リロードフラグが有効の場合、カスタム監視、ログファイル監視のリロードを行う
+				// IPアドレスに変化があった場合
+				if (isReloadMonitor()) {
+					m_log.info("reloading configuration");
+					reloadCommandMonitoring(updateInfo);
+					reloadLogfileMonitor();
+					UpdateModuleUtil.setAgentLibMd5();
+					setReloadFlg(false);
+				}
 
 				for (TopicInfo topicInfo : topicInfoList) {
 					m_log.info("getTopic facilityId=" + topicInfo.getFacilityId());
@@ -336,9 +349,24 @@ public class ReceiveTopic extends Thread {
 		m_log.info("reloading configuration of custom monitoring...");
 		try {
 			dtos = AgentEndPointWrapper.getCommandExecuteDTOs();
-
+			
+			// unregister unnecessary Command Collector
+			for (CollectorId collectId : CollectorManager.getAllCollectorIds()) {
+				if (collectId.type != CommandCollector._collectorType) {
+					continue;
+				}
+				boolean unnecessary = true;
+				for (CommandExecuteDTO dto : dtos) {
+					if (collectId.id != null && collectId.id.equals(dto.getMonitorId())) {
+						unnecessary = false;
+					}
+				}
+				if (unnecessary) {
+					CollectorManager.unregisterCollectorTask(collectId);
+				}
+			}
+			
 			// reset Command Collector
-			CollectorManager.unregisterCollectorTask(PluginConstant.TYPE_CUSTOM_MONITOR);
 			for (CommandExecuteDTO dto : dtos) {
 				m_log.info("reloaded configuration : " + CommandMonitoringWSUtil.toStringCommandExecuteDTO(dto));
 				CollectorManager.registerCollectorTask(new CommandCollector(dto));
@@ -504,6 +532,20 @@ public class ReceiveTopic extends Thread {
 		return m_clearFlg;
 	}
 
+	/**
+	 * reloadFlgの設定
+	 */
+	synchronized public static void setReloadFlg(boolean reloadFlg) {
+		m_reloadFlg = reloadFlg;
+	}
+	
+	/**
+	 * reloadFlgの取得
+	 */
+	synchronized public static boolean isReloadMonitor() {
+		return m_reloadFlg;
+	}
+	
 	/**
 	 * ジョブ実行履歴削除
 	 * 通信エラーとなった場合に、一定時間後、ジョブ履歴情報を削除する
