@@ -82,6 +82,8 @@ public class LogfileMonitor {
 	private static final String HINEMOS_LOG_AGENT = "hinemos_log_agent";
 
 	private LogfileMonitorManager m_logfileMonitorManager;
+	
+	private boolean m_logfileMessageFlag = false;
 
 	/**
 	 * このオブジェクトはログファイルに紐づいている。
@@ -91,9 +93,17 @@ public class LogfileMonitor {
 
 	/** ログファイル名 */
 	private String m_filePath;
+	
+	private File file;
 
 	/** 動作間隔（ミリ秒） */
 	private int m_runInterval;
+	
+	/**
+	 * ファイルを初めから読むためのフラグ
+	 * logfile.regexpがtrueの時のみ有効
+	 */
+	private boolean m_headOpenFlag = false;
 
 	/** 初回ファイルチェック時にファイルが存在せず、初めてファイルを読み込んだ際に先頭から読むか否か */
 	private boolean m_firstHeadOpen = false;
@@ -153,10 +163,11 @@ public class LogfileMonitor {
 	 *            最初にファイルをチェック
 	 */
 	public LogfileMonitor(LogfileMonitorManager logfileManager,
-			String path, int runInterval) {
+			String path, int runInterval, boolean headOpenFlag) {
 		m_logfileMonitorManager = logfileManager;
 		m_filePath = path;
 		m_runInterval = runInterval;
+		m_headOpenFlag = headOpenFlag;
 
 		// ファイル変更チェック期間（秒）
 		String sleepInterval = AgentProperties.getProperty(UNCHANGED_STATS_PERIOD, "5");
@@ -234,6 +245,14 @@ public class LogfileMonitor {
 				m_log.error("limit.logmsg",e);
 			}
 		}
+		
+		// オリジナルメッセージにログファイル名を含めるか否か
+		String key = "logfile.full.message";
+		String logfileMessageStr = AgentProperties.getProperty(key);
+		if ("true".equals(logfileMessageStr)) {
+			m_logfileMessageFlag = true;
+		}
+		m_log.info(key + " = " + m_logfileMessageFlag);
 	}
 
 	public void setMonitor(ArrayList<MonitorInfo> monitorInfoList) {
@@ -278,7 +297,7 @@ public class LogfileMonitor {
 				+ "  logfile encoding : " + m_logEncoding
 				+ "  syslog encoding : " + System.getProperty("file.encoding"));
 		// ファイルオープン
-		File file = new File(m_filePath);
+		file = new File(m_filePath);
 
 		if (m_fr == null) {
 			// ログローテートまたは、初回読み込みでなく、firstHeadOpenフラグがtrueかつFileNotFoundが前回おきた場合は先頭から読む
@@ -288,6 +307,8 @@ public class LogfileMonitor {
 				m_log.debug("run() : m_firstHeadOpenStatus=" + m_firstHeadOpenStatus);
 				m_log.debug("run() : m_firstHeadOpen=" + m_firstHeadOpen);
 				m_fr = openFile(file, false);
+			} else if (m_headOpenFlag) {
+				m_fr = openFile(file, false);
 			}
 			// 初回読み込みは必ず末尾から読む
 			// 2回目以降かつ、firstHeadOpenフラグがfalseの場合は末尾から読む
@@ -446,7 +467,7 @@ public class LogfileMonitor {
 			if (m_filesize < m_tmp_filesize) {
 				// デバッグログ
 				m_log.debug("run() : " + m_filePath +
-						" filesize " + m_filesize + " tmp_filesize " + m_tmp_filesize);
+						" filesize " + m_filesize + " tmp_ilesize " + m_tmp_filesize);
 
 				while (true) {
 					readSuccessFlg = false;
@@ -616,6 +637,9 @@ public class LogfileMonitor {
 				}
 				String patternText = stringInfo.getPattern();
 				String message = "log.line=" + line + "\npattern=" + patternText;
+				if (m_logfileMessageFlag) {
+					message = "log.file=" + file.getAbsolutePath() + "\n" + message;
+				}
 				m_log.trace("check " + message);
 
 				Pattern pattern = null;
