@@ -81,7 +81,7 @@ JAVA_OPTS="-Xms32m -Xmx32m"
 
 ## for OutOfMemory
 JAVA_OPTS="${JAVA_OPTS} -XX:+HeapDumpOnOutOfMemoryError -XX:HeapDumpPath=${HINEMOS_AGENT_HOME}/var/log"
-export _JAVA_OPTIONS="-XX:OnOutOfMemoryError='$JAVA_HOME/bin/jmap -F -histo %p >> ${HINEMOS_AGENT_HOME}/var/log/agent_outofmemory_histgram.log'"
+export _JAVA_OPTIONS="-XX:OnOutOfMemoryError='$JAVA_HOME/bin/jmap -histo %p >> ${HINEMOS_AGENT_HOME}/var/log/agent_outofmemory_histgram.log'"
 
 ## for hostname
 HOSTNAME=`hostname`
